@@ -8,7 +8,7 @@
 #'  \dQuote{named} (default) checks \code{x} to be named which excludes names to be \code{NA} or emtpy (\code{""}).
 #'  \dQuote{unique} additionally tests for non-duplicated names.
 #'  \dQuote{strict} checks for unique names which comply to R's variable name restrictions.
-#'  Note that for zero-length \code{x} every name check evalutes to \code{TRUE}.
+#'  Note that for zero-length \code{x} every name check evaluates to \code{TRUE}.
 #'  Also note that you can use \code{\link{checkSubset}} to check for a specific set of names.
 #' @template checker
 #' @useDynLib checkmate c_check_named
@@ -19,30 +19,31 @@
 #' names(x) = letters[1:3]
 #' testNamed(x, "unique")
 checkNamed = function(x, type = "named") {
-  .Call("c_check_named", x, type, PACKAGE = "checkmate")
+  .Call(c_check_named, x, type)
 }
 
-#' @rdname checkNamed
-#' @useDynLib checkmate c_check_named
 #' @export
-assertNamed = function(x, type = "named", add = NULL, .var.name) {
-  res = .Call("c_check_named", x, type, PACKAGE = "checkmate")
-  makeAssertion(res, vname(x, .var.name), add)
-}
-
+#' @include makeAssertion.r
+#' @template assert
 #' @rdname checkNamed
-#' @useDynLib checkmate c_check_named
-#' @export
-testNamed = function(x, type = "named") {
-  res = .Call("c_check_named", x, type, PACKAGE = "checkmate")
-  isTRUE(res)
-}
+assertNamed = makeAssertionFunction(checkNamed)
 
-# #' @rdname checkNamed
-# #' @useDynLib checkmate c_check_named
-# #' @template expect
+#' @export
+#' @rdname checkNamed
+assert_named = assertNamed
+
+#' @export
+#' @include makeTest.r
+#' @rdname checkNamed
+testNamed = makeTestFunction(checkNamed)
+
+#' @export
+#' @rdname checkNamed
+test_named = testNamed
+
+# This function is already provided by testthat
 # #' @export
-# expect_named = function(x, type = "named", info = NULL, label = NULL) {
-#   res = .Call("c_check_named", x, type, PACKAGE = "checkmate")
-#   makeExpectation(res, info = info, label = vname(x, label))
-# }
+# #' @include makeExpectation.r
+# #' @template expect
+# #' @rdname checkNamed
+expect_named = makeExpectationFunction(checkNamed)
