@@ -9,12 +9,12 @@
 #' @param type [character(1)]\cr
 #'  Select the check(s) to perform.
 #'  \dQuote{unnamed} checks \code{x} to be \code{NULL}.
-#'  \dQuote{named} (default) checks \code{x} for reguluar names which excludes names to be \code{NA} or emtpy (\code{""}).
+#'  \dQuote{named} (default) checks \code{x} for regular names which excludes names to be \code{NA} or empty (\code{""}).
 #'  \dQuote{unique} additionally tests for non-duplicated names.
 #'  \dQuote{strict} checks for unique names which comply to R's variable name restrictions.
 #'  Note that you can use \code{\link{checkSubset}} to check for a specific set of names.
 #' @template checker
-#' @useDynLib checkmate c_check_named
+#' @useDynLib checkmate c_check_names
 #' @export
 #' @examples
 #' x = 1:3
@@ -22,30 +22,30 @@
 #' names(x) = letters[1:3]
 #' testNames(x, "unique")
 checkNames = function(x, type = "named") {
-  .Call("c_check_names", x, type, PACKAGE = "checkmate")
+  .Call(c_check_names, x, type)
 }
 
-#' @rdname checkNames
-#' @useDynLib checkmate c_check_names
 #' @export
-assertNames = function(x, type = "named", add = NULL, .var.name) {
-  res = .Call("c_check_names", x, type, PACKAGE = "checkmate")
-  makeAssertion(res, vname(x, .var.name), add)
-}
-
+#' @include makeAssertion.r
+#' @template assert
 #' @rdname checkNames
-#' @useDynLib checkmate c_check_names
+assertNames = makeAssertionFunction(checkNames)
+
 #' @export
-testNames = function(x, type = "named") {
-  res = .Call("c_check_names", x, type, PACKAGE = "checkmate")
-  isTRUE(res)
-}
-
 #' @rdname checkNames
+assert_names = assertNames
+
+#' @export
+#' @include makeTest.r
+#' @rdname checkNames
+testNames = makeTestFunction(checkNames)
+
+#' @export
+#' @rdname checkNames
+test_names = testNames
+
+#' @export
+#' @include makeExpectation.r
 #' @template expect
-#' @useDynLib checkmate c_check_names
-#' @export
-expect_names = function(x, type = "named", info = NULL, label = NULL) {
-  res = .Call("c_check_names", x, type, PACKAGE = "checkmate")
-  makeExpectation(res, info = info, label = vname(x, label))
-}
+#' @rdname checkNames
+expect_names = makeExpectationFunction(checkNames)
