@@ -13,30 +13,30 @@
 #' testScalar(1)
 #' testScalar(1:10)
 checkScalar = function(x, na.ok = FALSE) {
-  .Call("c_check_scalar", x, na.ok, PACKAGE = "checkmate")
+  .Call(c_check_scalar, x, na.ok)
 }
 
-#' @rdname checkScalar
-#' @useDynLib checkmate c_check_scalar
 #' @export
-assertScalar = function(x, na.ok = FALSE, add = NULL, .var.name) {
-  res = .Call("c_check_scalar", x, na.ok, PACKAGE = "checkmate")
-  makeAssertion(res, vname(x, .var.name), add)
-}
-
+#' @include makeAssertion.r
+#' @template assert
 #' @rdname checkScalar
-#' @useDynLib checkmate c_check_scalar
+assertScalar = makeAssertionFunction(checkScalar)
+
 #' @export
-testScalar = function(x, na.ok = FALSE) {
-  res = .Call("c_check_scalar", x, na.ok, PACKAGE = "checkmate")
-  isTRUE(res)
-}
-
 #' @rdname checkScalar
+assert_scalar = assertScalar
+
+#' @export
+#' @include makeTest.r
+#' @rdname checkScalar
+testScalar = makeTestFunction(checkScalar)
+
+#' @export
+#' @rdname checkScalar
+test_scalar = testScalar
+
+#' @export
+#' @include makeExpectation.r
 #' @template expect
-#' @useDynLib checkmate c_check_scalar
-#' @export
-expect_scalar = function(x, na.ok = FALSE, info = NULL, label = NULL) {
-  res = .Call("c_check_scalar", x, na.ok, PACKAGE = "checkmate")
-  makeExpectation(res, info = info, label = vname(x, label))
-}
+#' @rdname checkScalar
+expect_scalar = makeExpectationFunction(checkScalar)
