@@ -1,7 +1,8 @@
 context("checkScalarNA")
 
 test_that("checkScalarNA", {
-  expect_true(testScalarNA(NA))
+  expect_succ_all("ScalarNA", NA)
+  expect_fail_all("ScalarNA", 1)
   expect_true(testScalarNA(NA_real_))
   expect_false(testScalarNA(1))
   expect_false(testScalarNA(rep(NA_character_, 2)))
